@@ -3,7 +3,7 @@ package Pet::Cat;
 use Soo;
 
 
-extends "Pet";
+extends 'Pet';
 
 has fly => { default => 'I cannot fly' };
 has talk => { default => 'meow' };
